<?php
/*
 * Plugin Name: Decentralized Bitcoin CryptoDEC Payment Gateway for WooCommerce
 * Plugin URI: https://wordpress.org/plugins/decentralized-bitcoin-cryptodec-payment-gateway-for-woocommerce/
 * Description: Take decentrolized payments in Bitcoin on your store without middleman for free.
 * Author: ITLS
 * Author URI: https://ampae.com
 * Version: 2.0.2
 * Text Domain: decentralized-bitcoin-cryptodec-payment-gateway-for-woocommerce
 *
 * License: GPLv3
 *
 * GitHub Plugin URI: #
 * GitHub Branch: master
 *
 * @author ITLS
 * @since  1.0
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Tested up to: 5.8
 * WC tested up to: 5.6
 */

if (! defined('ABSPATH')) {
    exit;
}

register_activation_hook(__FILE__, 'ITLS_cryptodec_activate');
register_deactivation_hook(__FILE__, 'ITLS_cryptodec_deactivate');
register_uninstall_hook(__FILE__, 'ITLS_cryptodec_uninstall');

$itls_wc_pay_gw_x1x_data = array(

    'full_name'         => 'CryptoDecPaymentGateway',
    'full_author'       => 'ITLS',
    'version'           => '2.0.2',

    'settings_version'  => '4',

    'menu_icon'         => 'dashicons-lock',
    'menu_position'     => '4.75',

    'debug'             => false,

);

$itls_wc_pay_gw_x1x_data['owner'] = array(
        'logo'               => array(
            'img' => plugin_dir_url(__FILE__) . '/assets/images/logox.png',
            'link' =>'#',
        ),
        'name'               => array(
            'label' => $itls_wc_pay_gw_x1x_data['full_name'],
            'tag' => 'h2',
        ),
        'ver'               => array(
            'label' => 'Version:',
            'info' => $itls_wc_pay_gw_x1x_data['version'],
        ),
);

include_once plugin_dir_path(__FILE__) . 'lib/itls-wp-helper.php';

$itls_wc_pay_gw_tabs_exclude = array();

$itls_wc_pay_gw_x1x_data['name']            = ITLS_text2slug($itls_wc_pay_gw_x1x_data['full_name']);
$itls_wc_pay_gw_x1x_data['author']          = ITLS_text2slug($itls_wc_pay_gw_x1x_data['full_author']);
$itls_wc_pay_gw_x1x_data['prefix']          = $itls_wc_pay_gw_x1x_data['author'].'_'.$itls_wc_pay_gw_x1x_data['name'];
$itls_wc_pay_gw_x1x_data['url_prefix']      = $itls_wc_pay_gw_x1x_data['author'].'-'.$itls_wc_pay_gw_x1x_data['name'];
$itls_wc_pay_gw_x1x_data['options_name']    = $itls_wc_pay_gw_x1x_data['prefix'].''.$itls_wc_pay_gw_x1x_data['settings_version'];
$itls_wc_pay_gw_x1x_data['settings_name']   = $itls_wc_pay_gw_x1x_data['prefix'].'_settings'.''.$itls_wc_pay_gw_x1x_data['settings_version'];

define(strtoupper($itls_wc_pay_gw_x1x_data['prefix']) . '_VERSION', $itls_wc_pay_gw_x1x_data['version'].time());
define(strtoupper($itls_wc_pay_gw_x1x_data['prefix']) . '_DIR', plugin_dir_path(__FILE__));
define(strtoupper($itls_wc_pay_gw_x1x_data['prefix']) . '_URL', plugin_dir_url(__FILE__));
define(strtoupper($itls_wc_pay_gw_x1x_data['prefix']) . '_DOMAIN', get_bloginfo('url'));
define(strtoupper($itls_wc_pay_gw_x1x_data['prefix']) . '_COOKIEPATH', '/');

if (is_admin()) {
    $itls_wc_pay_gw_x1x_data['admin_menu'] = array(
            'page_title' => 'Crypto DEC '.' Options',
            'menu_name'  => 'Crypto DEC',
            'menu_title' => 'General Settings',
            'capability' => 'manage_options',
            'menu_slug'  => $itls_wc_pay_gw_x1x_data['url_prefix'].'-options-page',
            'function'   => $itls_wc_pay_gw_x1x_data['prefix'].'_options_page',
            'icon_url'   => $itls_wc_pay_gw_x1x_data['menu_icon'],
            'position'   => $itls_wc_pay_gw_x1x_data['menu_position']
    );

    $itls_wc_pay_gw_x1x_data['admin_submenu'] = array(
            'page_title' => 'Reset '.$itls_wc_pay_gw_x1x_data['full_name'].' Options',
            'menu_title' => 'Reset Settings',
            'menu_slug'  => $itls_wc_pay_gw_x1x_data['url_prefix'].'-reset-options',
            'menu_page'  => $itls_wc_pay_gw_x1x_data['prefix'].'_reset_options_page'
    );

    include_once plugin_dir_path(__FILE__).'admin/core.php';
}

function ITLS_add_interval($schedules)
{
    $schedules['seconds_5'] = array('interval'=>5, 'display'=>'debug');
    $schedules['seconds_30'] = array('interval'=>30, 'display'=>'Bi-minutely');
    $schedules['minutes_1'] = array('interval'=>60, 'display'=>'Once every 1 minute');
    $schedules['minutes_2'] = array('interval'=>120, 'display'=>'Once every 2 minutes');

    return $schedules;
}

function ITLS_cryptodec_activate()
{
    if (!wp_next_scheduled('ITLS_dp_gw_task_hook')) {
        wp_schedule_event(time(), 'seconds_30', 'ITLS_dp_gw_task_hook');
    }
    include_once(dirname(__FILE__). '/inc/model-setup.php');

    ITLS_cd_create_payment_table();
}

function ITLS_cryptodec_deactivate()
{
    wp_clear_scheduled_hook('ITLS_dp_gw_task_hook');
}

function ITLS_cryptodec_uninstall()
{
    include_once(dirname(__FILE__). '/inc/model-setup.php');
    ITLS_cd_drop_payment_table();
}

/**
 * Checked Woocommerce activation
 */
if (in_array('woocommerce/woocommerce.php', apply_filters('active_plugins', get_option('active_plugins')))) {
    include_once plugin_dir_path(__FILE__) . 'lib/itls-wp-helper-class.php';
    $itls_wp_helper = new \Itls\Core\WpHelper();

    include_once(dirname(__FILE__). '/inc/itls-btc-class.php');
    $itls_btc = new \Itls\Crypto\Btc();

    include_once(dirname(__FILE__). '/inc/itls-btc-wp-class.php');
    $itls_btc_wp = new \Itls\CryptoWp\Btc();

    include_once(dirname(__FILE__). '/inc/sochain-v1-class.php');
    $sochain = new \Itls\Crypto\SoChainV1();

    function cryptodec_init_gateway_class()
    {
        function cryptodec_payment_gateway_class($gateways)
        {
            $gateways[] = 'WC_CryptoDec_Gateway'; // your class name is here
            return $gateways;
        }

        include_once(dirname(__FILE__). '/inc/model.php');

        include_once(dirname(__FILE__). '/inc/cron.php');

        include_once(dirname(__FILE__). '/inc/plugin.php');

        add_filter('woocommerce_payment_gateways', 'cryptodec_payment_gateway_class');
        include_once(dirname(__FILE__). '/inc/itls-crypto-dec-payment-gateway-class.php');

        add_filter ('cron_schedules', 'ITLS_add_interval');

        add_action('ITLS_dp_gw_task_hook', 'ITLS_do_action');
    }

    add_action('plugins_loaded', 'cryptodec_init_gateway_class');

    add_filter('woocommerce_my_account_my_orders_actions', 'remove_myaccount_orders_cancel_button', 10, 2);
    function remove_myaccount_orders_cancel_button( $actions, $order ){
      unset($actions['cancel']);
      return $actions;
    }

    add_filter('woocommerce_my_account_my_orders_actions', 'remove_myaccount_orders_pay_button', 10, 2);
    function remove_myaccount_orders_pay_button( $actions, $order ){
      unset($actions['pay']);
      return $actions;
    }

} else {

    add_action('admin_notices', 'cryptodec_admin_notice__error');
    function cryptodec_admin_notice__error()
    {
        ?>
        <div class="notice notice-error">
            <p><a href="http://wordpress.org/extend/plugins/woocommerce/"><?php esc_html_e('Woocommerce', 'decentralized-bitcoin-cryptodec-payment-gateway-for-woocommerce'); ?></a> <?php esc_html_e('plugin required to actived if you want to install this plugin.', 'decentralized-bitcoin-cryptodec-payment-gateway-for-woocommerce'); ?></p>
        </div>
        <?php
    }
    function cryptodec_err_deactivate()
    {
        deactivate_plugins(plugin_basename(__FILE__));
        unset($_GET['activate']);
    }
    add_action('admin_init', 'cryptodec_err_deactivate');
}
