<?php
        class WC_CryptoDec_Gateway extends WC_Payment_Gateway
        {
            public function __construct()
            {
                global $itls_btc_wp;
                $this->id = 'cryptodec_gateway'; // payment gateway plugin ID
                $this->icon = plugin_dir_url(__FILE__) . '../assets/images/btc-logo-3.png'; // URL of the icon that will be displayed on checkout page near your gateway name
                $this->has_fields = true; // txid form
                $this->method_title = 'Decentralized Crypto Payments';
                $this->method_description = 'Enables your customers to pay using Bitcoin directly to your wallet.'; // will be displayed on the options page

                $this->supports = array(
                    'products'
                );

                // Method with all the options fields
                $this->init_form_fields();

                // Load the settings.
                $this->init_settings();
                $this->enabled = $this->get_option('enabled');
                $this->title = $this->get_option('title');
                $this->description = $this->get_option('description');
                $this->cryptodec_btc_address = $itls_btc_wp->get_btc_addr();

                // This action hook saves the settings
                add_action('woocommerce_update_options_payment_gateways_' . $this->id, array( $this, 'process_admin_options' ));
            }


            public function admin_options()
            {
                ?>
                <h2>Crypto DEC Payments</h2>
                <div class="itls-cd-options">
                    <table class="form-table">
                        <?php $this->generate_settings_html(); ?>
                    </table>
                    <a href=<?php echo get_site_url() . '/wp-admin/admin.php?page=itls-cryptodecpaymentgateway-options-page#itls-cryptodec-gw-adm-tab-general'?>>Crypto DEC Plugin Settings</a>
                </div>
                <?php
            }

            /**
              * Plugin options
              */
            public function init_form_fields()
            {
                $this->form_fields = array(
                    'enabled' => array(
                        'title'       => esc_html__('Enable/Disable', "decentralized-bitcoin-cryptodec-payment-gateway-for-woocommerce"),
                        'label'       => esc_html__('Enable CryptoDec Gateway', "decentralized-bitcoin-cryptodec-payment-gateway-for-woocommerce"),
                        'type'        => 'checkbox',
                        'description' => '',
                        'default'     => 'no'
                    ),
                    'title' => array(
                        'title'       => esc_html__('Title', "decentralized-bitcoin-cryptodec-payment-gateway-for-woocommerce"),
                        'type'        => 'text',
                        'description' => esc_html__('This controls the title which the user sees during checkout.', "decentralized-bitcoin-cryptodec-payment-gateway-for-woocommerce"),
                        'default'     => esc_html__('Pay with BTC', "decentralized-bitcoin-cryptodec-payment-gateway-for-woocommerce"),
                        'desc_tip'    => true,
                    ),

                );
            }

            public function payment_fields()
            {
                global $woocommerce, $itls_btc, $itls_btc_wp; ?>
				<div class="payment-method-cryptodec">
<?php
                $cart_total = WC()->cart->total; // $woocommerce->cart->total;
                $btc_coin = 'BTC';
                $curr_code = get_woocommerce_currency();

                if ($curr_code!=$btc_coin) {
                    $btc_amount = $itls_btc->getBtcAmount($cart_total, $curr_code);
                } else {
                    $btc_amount = $cart_total;
                }

                if ($btc_amount < 0.00000001) {
                    wc_add_notice(esc_html__('BTC Exchange Rate can nott be obtained', 'decentralized-bitcoin-cryptodec-payment-gateway-for-woocommerce'), 'error');
                    //add_filter( 'woocommerce_available_payment_gateways', 'ITLS_cryptodec_gateway_disable' );
                    echo wpautop(wptexturize('<strong>This Payment Method currently can not be used.</strong><br />'));
                    return false;
                }

                if ($this->cryptodec_btc_address) {
                    $qrCode = $itls_btc_wp->get_qr_code($this->cryptodec_btc_address, $btc_amount);
                    echo wpautop(wptexturize("Transfer amount in BTC: <input value='".$btc_amount."' name='cryptodec_btc_amount' /><br />"));
                    echo wpautop(wptexturize("BTC Wallet: <input value='". $this->cryptodec_btc_address."' style='width:110%;' name='cryptodec_wallet_address' /><br />"));
?>
                    <div style="width:100%;  height:170px; background-color:#fff;">
                      <div style="display: block; margin-left: auto; margin-right: auto; width: 50%;">
                      <p>Copy/Scan</p>
                      <img height="120" width="120" style="display: block;  max-width:120px;  max-height:120px;  width: auto;  height: auto;" src=<?php echo $qrCode; ?> alt="<?php echo $this->cryptodec_btc_address; ?>" />
                    </div></div>
<?php
                    echo wpautop(wptexturize('Amount to transfer should be EXACT. Transactions with different amount may be delayed or rejected.'));

                    echo wpautop(wptexturize("After transfer is made fill in <strong>Transaction ID</strong> below then hit Place Order button.<br />"));
                } else {
                    wc_add_notice(esc_html__('BTC Wallet Address Not Found', 'decentralized-bitcoin-cryptodec-payment-gateway-for-woocommerce'), 'error');
                    //add_filter( 'woocommerce_available_payment_gateways', 'ITLS_cryptodec_gateway_disable' );
                    echo wpautop(wptexturize('<strong>This Payment Method currently can not be used.</strong><br />'));
                    return false;
                }
?>
			    	<input type="text" name="cryptodec_transaction_id" id="cryptodec_transaction_id" style="width:100%;" placeholder="Transaction ID">
			    	<input value="<?php echo $this->cryptodec_btc_address; ?>" type="hidden" name="cryptodec_best_btc_wallet" id="cryptodec_best_btc_wallet">
			    	<input value="<?php echo $btc_amount; ?>" type="hidden" name="cryptodec_total" id="cryptodec_total">
            <input value="<?php echo $btc_coin; ?>" type="hidden" name="cryptodec_coin" id="cryptodec_coin">
				</div>


			<?php
            }

            /*
             * We're processing the payments here
             */
            public function process_payment($order_id)
            {
                global $woocommerce;
                $order = new WC_Order($order_id);

                $status = 'pending';
                $order->update_status($status, esc_html__('Checkout with CryptoDEC payment. ', "decentralized-bitcoin-cryptodec-payment-gateway-for-woocommerce"));

                // Reduce stock levels
                $order->reduce_order_stock();

                // Remove cart
                $woocommerce->cart->empty_cart();

                // Return thankyou redirect
                return array(
                    'result' => 'success',
                    'redirect' => $this->get_return_url($order)
                );
            }
        }
