<?php
namespace Itls\Crypto;

if (!class_exists('\Itls\Crypto\SoChainV1')) {
    class SoChainV1
    {
        private $req_addr = 'https://sochain.com/api/v2/address';
        private $req_txid = 'https://sochain.com/api/v2/is_tx_confirmed';


        public function __construct()
        {
        }

        public function getFresh($my_addrsa)
        {
            $res = null;
            $tmpres = null;
            $tmpx = array();
            if(empty($my_addrsa)){
                return false;
            }
            foreach ($my_addrsa as $my_addr) {
                $tmpRes = $this->getLastTime($my_addr);
                $tmpx[$my_addr] = $tmpRes;
            }
            asort($tmpx);
            $res = array_key_first($tmpx);
            return $res;
        }

        public function getLastTime($my_addr, $curr = 'BTC')
        {
            $res = null;
            $bcinfo = $this->getRemote($this->req_addr."/".$curr."/".$my_addr);
            if (isset($bcinfo['data']['txs'])) {
                $res = 0;
            }
            if (isset($bcinfo['data']['txs'][0]['time'])) {
                $res = $bcinfo['data']['txs'][0]['time'];
            }
            return $res;
        }

        public function confirm($my_addr, $amo, $curr='BTC', $con_min = 0, $con_max = 10)
        {
            $res = false;

            $bcinfo = $this->getRemote($this->req_addr."/".$curr."/".$my_addr);

            if (isset($bcinfo['data']['txs'])) {
                foreach ($bcinfo['data']['txs'] as $k => $v) {
                    if (isset($v['incoming'])) {
                        if ($v['incoming']['value']==$amo && $v['confirmations'] >= $con_min && $v['confirmations'] < $con_max) {
                            $res = $v['txid'];
                            break;
                        }
                    }
                }
            }
            return $res;
        }

        public function getTxid($my_addr, $amo, $curr='BTC', $con_max = 3, $ttl = 1200)
        {
            $res = false;

            $bcinfo = $this->getRemote($this->req_addr."/".$curr."/".$my_addr);

            if (isset($bcinfo['data']['txs'])) {
                foreach ($bcinfo['data']['txs'] as $k => $v) {
                    if (isset($v['incoming'])) {
                        if ($v['incoming']['value']==$amo && (time() - $v['time']) < $ttl && $v['confirmations'] < $con_max) {
                            $res = $v['txid'];
                            break;
                        }
                    }
                }
            }
            return $res;
        }

        public function getIn($my_addr, $txid, $curr='BTC', $conf = 3)
        {
            $i = 0;
            $res = false;
            $bcinfo = $this->getRemote($this->req_addr."/".$curr."/".$my_addr);

            if (strlen($txid)>12) {
                if (isset($bcinfo['data']['txs'])) {
                    foreach ($bcinfo['data']['txs'] as $k => $v) {
                        if ($v['txid'] == $txid) {
                            if (isset($v['incoming'])) {
                                if ($conf<$v['confirmations']) {
                                    $res = $v['incoming']['value'];
                                } else {
                                    $res = 0;
                                }
                            } else {
                                $res = -1; // outgoing transaction !
                            }
                            break;
                        }
                        $i++;
                        if ($i>50) {
                            break;
                        }
                    }
                }
            }
            return $res;
        }

        //==============================================================================

        public function getAllFreshTxid($my_addr, $curr = 'BTC', $ttl = 7200)
        {
            $res = array();

            $bcinfo = $this->getRemote($this->req_addr."/".$curr."/".$my_addr);
            if (isset($bcinfo['data']['txs'])) {
                foreach ($bcinfo['data']['txs'] as $data) {
                    $tmp = time() - $data['time'];
                    if ($tmp < $ttl) {
                        $res[] = $data['txid'];
                    }
                }
            }
            return $res;
        }


        public function getConfirmations($txid, $curr = 'BTC')
        {
            $res = -1;

            $bcinfo = $this->getRemote($this->req_txid.'/'.$curr.'/'.$txid);


            if (isset($bcinfo['data']['confirmations'])) {
                $res = $bcinfo['data']['confirmations'];
            }
            return $res;
        }

        /**
         * Pull the feed
         */
        public function getRemote($url)
        {
            // remote data
            $response = wp_remote_get($url);

            if (is_wp_error($response) || !isset($response['body'])) {
                return;
            } // bad response

            // the good stuff
            $body = wp_remote_retrieve_body($response);

            if (is_wp_error($body)) {
                return;
            } // bad body

            // decode the data
            $data = json_decode($body, true);

            if (!$data || empty($data)) {
                return;
            } // bad data

            // final remote data
            return $data;
        }
    }
}
